@@ -144,7 +144,7 @@ class BillingConductorClient(BaseClient):
         *,
         TargetArn: str,
         ResourceArns: Sequence[str],
-        BillingPeriodRange: "CustomLineItemBillingPeriodRangeTypeDef" = ...
+        BillingPeriodRange: CustomLineItemBillingPeriodRangeTypeDef = ...
     ) -> BatchAssociateResourcesToCustomLineItemOutputTypeDef:
         """
         Associates a batch of resources to a percentage custom line item.
@@ -158,7 +158,7 @@ class BillingConductorClient(BaseClient):
         *,
         TargetArn: str,
         ResourceArns: Sequence[str],
-        BillingPeriodRange: "CustomLineItemBillingPeriodRangeTypeDef" = ...
+        BillingPeriodRange: CustomLineItemBillingPeriodRangeTypeDef = ...
     ) -> BatchDisassociateResourcesFromCustomLineItemOutputTypeDef:
         """
         Disassociates a batch of resources from a percentage custom line item.
@@ -179,8 +179,8 @@ class BillingConductorClient(BaseClient):
         self,
         *,
         Name: str,
-        AccountGrouping: "AccountGroupingTypeDef",
-        ComputationPreference: "ComputationPreferenceTypeDef",
+        AccountGrouping: AccountGroupingTypeDef,
+        ComputationPreference: ComputationPreferenceTypeDef,
         ClientToken: str = ...,
         PrimaryAccountId: str = ...,
         Description: str = ...,
@@ -200,9 +200,9 @@ class BillingConductorClient(BaseClient):
         Name: str,
         Description: str,
         BillingGroupArn: str,
-        ChargeDetails: "CustomLineItemChargeDetailsTypeDef",
+        ChargeDetails: CustomLineItemChargeDetailsTypeDef,
         ClientToken: str = ...,
-        BillingPeriodRange: "CustomLineItemBillingPeriodRangeTypeDef" = ...,
+        BillingPeriodRange: CustomLineItemBillingPeriodRangeTypeDef = ...,
         Tags: Mapping[str, str] = ...
     ) -> CreateCustomLineItemOutputTypeDef:
         """
@@ -260,7 +260,7 @@ class BillingConductorClient(BaseClient):
         """
 
     def delete_custom_line_item(
-        self, *, Arn: str, BillingPeriodRange: "CustomLineItemBillingPeriodRangeTypeDef" = ...
+        self, *, Arn: str, BillingPeriodRange: CustomLineItemBillingPeriodRangeTypeDef = ...
     ) -> DeleteCustomLineItemOutputTypeDef:
         """
         Deletes the custom line item identified by the given ARN in the current, or
@@ -324,7 +324,7 @@ class BillingConductorClient(BaseClient):
         self,
         *,
         BillingPeriod: str = ...,
-        Filters: "ListAccountAssociationsFilterTypeDef" = ...,
+        Filters: ListAccountAssociationsFilterTypeDef = ...,
         NextToken: str = ...
     ) -> ListAccountAssociationsOutputTypeDef:
         """
@@ -341,7 +341,7 @@ class BillingConductorClient(BaseClient):
         BillingPeriod: str = ...,
         MaxResults: int = ...,
         NextToken: str = ...,
-        Filters: "ListBillingGroupCostReportsFilterTypeDef" = ...
+        Filters: ListBillingGroupCostReportsFilterTypeDef = ...
     ) -> ListBillingGroupCostReportsOutputTypeDef:
         """
         A paginated call to retrieve a summary report of actual Amazon Web Services
@@ -358,7 +358,7 @@ class BillingConductorClient(BaseClient):
         BillingPeriod: str = ...,
         MaxResults: int = ...,
         NextToken: str = ...,
-        Filters: "ListBillingGroupsFilterTypeDef" = ...
+        Filters: ListBillingGroupsFilterTypeDef = ...
     ) -> ListBillingGroupsOutputTypeDef:
         """
         A paginated call to retrieve a list of billing groups for the given billing
@@ -374,7 +374,7 @@ class BillingConductorClient(BaseClient):
         BillingPeriod: str = ...,
         MaxResults: int = ...,
         NextToken: str = ...,
-        Filters: "ListCustomLineItemsFilterTypeDef" = ...
+        Filters: ListCustomLineItemsFilterTypeDef = ...
     ) -> ListCustomLineItemsOutputTypeDef:
         """
         A paginated call to get a list of all custom line items (FFLIs) for the given
@@ -388,7 +388,7 @@ class BillingConductorClient(BaseClient):
         self,
         *,
         BillingPeriod: str = ...,
-        Filters: "ListPricingPlansFilterTypeDef" = ...,
+        Filters: ListPricingPlansFilterTypeDef = ...,
         MaxResults: int = ...,
         NextToken: str = ...
     ) -> ListPricingPlansOutputTypeDef:
@@ -418,7 +418,7 @@ class BillingConductorClient(BaseClient):
         self,
         *,
         BillingPeriod: str = ...,
-        Filters: "ListPricingRulesFilterTypeDef" = ...,
+        Filters: ListPricingRulesFilterTypeDef = ...,
         MaxResults: int = ...,
         NextToken: str = ...
     ) -> ListPricingRulesOutputTypeDef:
@@ -452,7 +452,7 @@ class BillingConductorClient(BaseClient):
         BillingPeriod: str = ...,
         MaxResults: int = ...,
         NextToken: str = ...,
-        Filters: "ListResourcesAssociatedToCustomLineItemFilterTypeDef" = ...
+        Filters: ListResourcesAssociatedToCustomLineItemFilterTypeDef = ...
     ) -> ListResourcesAssociatedToCustomLineItemOutputTypeDef:
         """
         List the resources associated to a custom line item.
@@ -491,7 +491,7 @@ class BillingConductorClient(BaseClient):
         Arn: str,
         Name: str = ...,
         Status: BillingGroupStatusType = ...,
-        ComputationPreference: "ComputationPreferenceTypeDef" = ...,
+        ComputationPreference: ComputationPreferenceTypeDef = ...,
         Description: str = ...
     ) -> UpdateBillingGroupOutputTypeDef:
         """
@@ -507,8 +507,8 @@ class BillingConductorClient(BaseClient):
         Arn: str,
         Name: str = ...,
         Description: str = ...,
-        ChargeDetails: "UpdateCustomLineItemChargeDetailsTypeDef" = ...,
-        BillingPeriodRange: "CustomLineItemBillingPeriodRangeTypeDef" = ...
+        ChargeDetails: UpdateCustomLineItemChargeDetailsTypeDef = ...,
+        BillingPeriodRange: CustomLineItemBillingPeriodRangeTypeDef = ...
     ) -> UpdateCustomLineItemOutputTypeDef:
         """
         Update an existing custom line item in the current or previous billing period.
